@@ -1,16 +1,14 @@
 from functools import wraps
-from typing import Callable
-from typing import Optional
+from typing import Callable, Optional
 
 from pika import BasicProperties
 
-from myrabbit.core.consumer.listener import Exchange
-from myrabbit.core.consumer.listener import Listener
-from myrabbit.core.consumer.listener import Queue
+from myrabbit.core.consumer.callbacks import Callbacks
+from myrabbit.core.consumer.listener import Exchange, Listener, Queue
 from myrabbit.core.consumer.pika_message import PikaMessage
-from myrabbit.core.publisher.reconnecting_publisher import ReconnectingPublisherFactory
-from myrabbit.core.serializer import JsonSerializer
-from myrabbit.core.serializer import Serializer
+from myrabbit.core.publisher.reconnecting_publisher import \
+    ReconnectingPublisherFactory
+from myrabbit.core.serializer import JsonSerializer, Serializer
 from myrabbit.events.event_with_message import EventWithMessage
 from myrabbit.events.listen_event_strategy.base import ListenEventStrategy
 from myrabbit.events.listen_event_strategy.service_pool import ServicePool
@@ -24,12 +22,17 @@ class EventBus:
         serializer: Optional[Serializer] = None,
         default_exchange_params: Optional[dict] = None,
         default_queue_params: Optional[dict] = None,
+        callbacks: Optional[Callbacks] = None,
     ):
         self._amqp_url = amqp_url
         self._serializer: Serializer = serializer or JsonSerializer()
         self.default_exchange_params = default_exchange_params or {}
         self.default_queue_params = default_queue_params or {}
         self._publisher_factory = ReconnectingPublisherFactory(self._amqp_url)
+        self._callbacks = callbacks
+
+    def set_callbacks(self, callbacks: Callbacks) -> None:
+        self._callbacks = callbacks
 
     def publish(
         self,
@@ -92,6 +95,7 @@ class EventBus:
             queue=Queue(**queue_params),
             routing_key=event_name,
             handle_message=deserialize_message,
+            callbacks=self._callbacks,
         )
 
     def _exchange(self, event_source: str) -> str:
